﻿Imports WpfNotes.Helper

Namespace Workspace
    Public Class HeaderWorkspace
        Inherits BaseClasses.ViewModelBase

        Private ReadOnly _mainWs As MainWorkspace

        Public Sub New()
            If Not IsInDesignMode Then
                Throw New Exception("Dieser Konstruktor ist nur für den DesignTime-Support!")
            End If
        End Sub

        Public Sub New(mainWs As MainWorkspace)
            If mainWs Is Nothing Then Throw New ArgumentNullException(NameOf(mainWs))
            _mainWs = mainWs
        End Sub


        Public ReadOnly Property ModeButtonText As String
            Get
                If _mainWs Is Nothing Then Return "Editierungsmodus nicht möglich"
                Return If(_mainWs.IsInEditMode, "Speichern und editieren beenden", "Editiermodus einschalten")
            End Get
        End Property


#Region "Commands"


        Private _switchEditableCommand As ICommand
        Public Property SwitchEditableCommand() As ICommand
            Get
                If _switchEditableCommand Is Nothing Then _
                    _switchEditableCommand = New RelayCommand(AddressOf SwitchEditableCommand_Execute,
                                                               AddressOf SwitchEditableCommand_CanExecute)
                Return _switchEditableCommand
            End Get
            Set(ByVal value As ICommand)
                _switchEditableCommand = value
                RaisePropertyChanged()
            End Set
        End Property

        Private Function SwitchEditableCommand_CanExecute(obj As Object) As Boolean
            Return _mainWs IsNot Nothing
        End Function

        Private Sub SwitchEditableCommand_Execute(obj As Object)
            _mainWs.IsInEditMode = Not _mainWs.IsInEditMode
            RaisePropertyChanged(NameOf(ModeButtonText))
        End Sub

        Private _manageCategoriesCommand As ICommand

        Public Property ManageCategoriesCommand() As ICommand
            Get
                If _manageCategoriesCommand Is Nothing Then _
                    _manageCategoriesCommand = New RelayCommand(AddressOf ManageCategoriesCommand_Execute,
                                                 AddressOf ManageCategoriesCommand_CanExecute)
                Return _manageCategoriesCommand
            End Get
            Set(ByVal value As ICommand)
                _manageCategoriesCommand = value
                RaisePropertyChanged()
            End Set
        End Property

        Private Function ManageCategoriesCommand_CanExecute(obj As Object) As Boolean
            Return _mainWs IsNot Nothing AndAlso _mainWs.IsInEditMode
        End Function

        Private Sub ManageCategoriesCommand_Execute(obj As Object)
            Dim catWindow As New ShowCategoriesWindow
            _mainWs.Ctx.SaveChanges()
            catWindow.ShowDialog()
            If RefreshDataCommand.CanExecute(Nothing) Then RefreshDataCommand.Execute(Nothing)
        End Sub


        Private _refreshDataCommand As ICommand

        Public Property RefreshDataCommand() As ICommand
            Get
                If _refreshDataCommand Is Nothing Then _
                    _refreshDataCommand = New RelayCommand(AddressOf RefreshDataCommand_Execute,
                                                 AddressOf RefreshDataCommand_CanExecute)
                Return _refreshDataCommand
            End Get
            Set(ByVal value As ICommand)
                _refreshDataCommand = value
                RaisePropertyChanged()
            End Set
        End Property

        Private Function RefreshDataCommand_CanExecute(obj As Object) As Boolean
            Return True
        End Function

        Private Sub RefreshDataCommand_Execute(obj As Object)
            _mainWs.Ctx.LoadContext()
            _mainWs.NotesWs.ReloadData()
            _mainWs.StatusWs.LastMessage = ""
        End Sub

#End Region





    End Class
End Namespace